pub struct FileOrFolderNamed(/* private fields */);Expand description
Defines a file or a folder with various name types. It is required that there exists exactly one file or folder with a given name description.
Implementations
Sourceimpl FileOrFolderNamed
impl FileOrFolderNamed
pub fn exact(name: impl Into<String>) -> Self
pub fn any(names: Vec<impl Into<String>>) -> Self
pub fn any_named(names: Vec<FileOrFolderNamed>) -> Self
pub fn regex(pattern: impl Into<String>) -> Self
pub fn wildmatch(pattern: impl Into<String>) -> Self
pub fn within(&self, directory: impl Into<PathBuf>) -> OneEntry
pub fn alias(&self, name: impl Into<String>) -> EntityAlias